pub struct Dependency {
pub selector: Option<Selector>,
pub tags: Option<Vec<ResourceProperty>>,
}Expand description
Represents a dependency that a node has on a resource.
The dependency is resolved by matching a resource against the selector’s constraints.
Fields
selector: Option<Selector>Trait Implementations
Sourceimpl Clone for Dependency
impl Clone for Dependency
Sourcefn clone(&self) -> Dependency
fn clone(&self) -> Dependency
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for Dependency
impl Debug for Dependency
Sourceimpl Default for Dependency
impl Default for Dependency
Sourcefn default() -> Dependency
fn default() -> Dependency
Returns the “default value” for a type. Read more
Sourceimpl<'a, ___E> Encode<Dependency<'static>, ___E> for &'a Dependencywhere
___E: Encoder + ?Sized,
impl<'a, ___E> Encode<Dependency<'static>, ___E> for &'a Dependencywhere
___E: Encoder + ?Sized,
Sourcefn encode(
self,
encoder: &mut ___E,
out: &mut MaybeUninit<Dependency<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder: &mut ___E, out: &mut MaybeUninit<Dependency<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<Dependency<'static>, ___E> for Dependencywhere
___E: Encoder + ?Sized,
impl<___E> Encode<Dependency<'static>, ___E> for Dependencywhere
___E: Encoder + ?Sized,
Sourcefn encode(
self,
encoder: &mut ___E,
out: &mut MaybeUninit<Dependency<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder: &mut ___E, out: &mut MaybeUninit<Dependency<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'de> FromWire<Dependency<'de>> for Dependency
impl<'de> FromWire<Dependency<'de>> for Dependency
Sourcefn from_wire(wire_: Dependency<'de>) -> Dependency
fn from_wire(wire_: Dependency<'de>) -> Dependency
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<Dependency<'de>> for Dependency
impl<'de> FromWireRef<Dependency<'de>> for Dependency
Sourcefn from_wire_ref(wire: &Dependency<'de>) -> Dependency
fn from_wire_ref(wire: &Dependency<'de>) -> Dependency
Converts the given reference to this type.
Sourceimpl PartialEq for Dependency
impl PartialEq for Dependency
Sourcefn eq(&self, other: &Dependency) -> bool
fn eq(&self, other: &Dependency) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for Dependency