#[repr(C)]pub struct DriverResumeRequest {
pub power_element_lease: OptionalEventPair,
}Expand description
The wire type corresponding to DriverResumeRequest.
Fields
power_element_lease: OptionalEventPairTrait Implementations
Sourceimpl Constrained for DriverResumeRequest
impl Constrained for DriverResumeRequest
Sourceimpl Debug for DriverResumeRequest
impl Debug for DriverResumeRequest
Sourceimpl<___D> Decode<___D> for DriverResumeRequestwhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
impl<___D> Decode<___D> for DriverResumeRequestwhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
Sourceimpl<___E> Encode<DriverResumeRequest, ___E> for DriverResumeRequestwhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
impl<___E> Encode<DriverResumeRequest, ___E> for DriverResumeRequestwhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, DriverResumeRequest>
const COPY_OPTIMIZATION: CopyOptimization<Self, DriverResumeRequest>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DriverResumeRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DriverResumeRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<DriverResumeRequest, ___E> for DriverResumeRequest<T0>where
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
T0: Encode<OptionalEventPair, ___E>,
impl<___E, T0> Encode<DriverResumeRequest, ___E> for DriverResumeRequest<T0>where
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
T0: Encode<OptionalEventPair, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DriverResumeRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DriverResumeRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<DriverResumeRequest> for DriverResumeRequest
impl FromWire<DriverResumeRequest> for DriverResumeRequest
Sourceconst COPY_OPTIMIZATION: CopyOptimization<DriverResumeRequest, Self>
const COPY_OPTIMIZATION: CopyOptimization<DriverResumeRequest, Self>
Sourcefn from_wire(wire: DriverResumeRequest) -> Self
fn from_wire(wire: DriverResumeRequest) -> Self
Converts the given owned value to this type.
Sourceimpl IntoNatural for DriverResumeRequest
impl IntoNatural for DriverResumeRequest
Sourcetype Natural = DriverResumeRequest
type Natural = DriverResumeRequest
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for DriverResumeRequest
impl Wire for DriverResumeRequest
Sourcetype Narrowed<'de> = DriverResumeRequest
type Narrowed<'de> = DriverResumeRequest
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.